[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
57/78: gnu: emacs-nodejs-repl: Improve package style.
From: |
guix-commits |
Subject: |
57/78: gnu: emacs-nodejs-repl: Improve package style. |
Date: |
Fri, 23 Feb 2024 03:12:12 -0500 (EST) |
sharlatan pushed a commit to branch go-team
in repository guix.
commit adedf338912f0ae4d6f5eda1cea63d64d36bb77c
Author: Nicolas Goaziou <mail@nicolasgoaziou.fr>
AuthorDate: Thu Feb 22 14:48:50 2024 +0100
gnu: emacs-nodejs-repl: Improve package style.
* gnu/packages/emacs-xyz.scm (emacs-nodejs-repl)[arguments]: Use
G-expressions. Use SEARCH-INPUT-FILES. Remove trailing #T. Remove
unnecessary call to MAKE-FILE-WRITABLE.
Change-Id: I9da1e24566359970cbf24129acb67f9f0610fb80
---
gnu/packages/emacs-xyz.scm | 43 ++++++++++++++++++++-----------------------
1 file changed, 20 insertions(+), 23 deletions(-)
diff --git a/gnu/packages/emacs-xyz.scm b/gnu/packages/emacs-xyz.scm
index f8cf5bf986..2bab584478 100644
--- a/gnu/packages/emacs-xyz.scm
+++ b/gnu/packages/emacs-xyz.scm
@@ -14146,29 +14146,26 @@ an Emacs buffer.")
(native-inputs
(list emacs-ert-expectations))
(arguments
- `(#:phases
- (modify-phases %standard-phases
- (add-after 'unpack 'set-shell
- ;; Setting the SHELL environment variable is required for the tests
- ;; to find sh.
- (lambda _
- (setenv "SHELL" (which "sh"))
- #t))
- (add-after 'unpack 'configure
- (lambda* (#:key inputs outputs #:allow-other-keys)
- (let ((node (assoc-ref inputs "node")))
- ;; Specify the absolute file names of the various
- ;; programs so that everything works out-of-the-box.
- (make-file-writable "nodejs-repl.el")
- (emacs-substitute-variables
- "nodejs-repl.el"
- ("nodejs-repl-command"
- (string-append node "/bin/node")))))))
- #:tests? #t
- #:test-command '("emacs" "-Q" "--batch"
- "-L" "."
- "-l" "test/test.el"
- "-f" "ert-run-tests-batch-and-exit")))
+ (list
+ #:phases
+ #~(modify-phases %standard-phases
+ (add-after 'unpack 'set-shell
+ ;; Setting the SHELL environment variable is required for the tests
+ ;; to find sh.
+ (lambda _
+ (setenv "SHELL" (which "sh"))))
+ (add-after 'unpack 'configure
+ (lambda* (#:key inputs #:allow-other-keys)
+ (let ((node (search-input-file inputs "/bin/node")))
+ ;; Specify the absolute file names of the various
+ ;; programs so that everything works out-of-the-box.
+ (emacs-substitute-variables "nodejs-repl.el"
+ ("nodejs-repl-command" node))))))
+ #:tests? #t
+ #:test-command #~(list "emacs" "-Q" "--batch"
+ "-L" "."
+ "-l" "test/test.el"
+ "-f" "ert-run-tests-batch-and-exit")))
(home-page "https://github.com/abicky/nodejs-repl.el")
(synopsis "Node.js REPL inside Emacs")
(description
- 12/78: gnu: python-schema-salad: Update to 8.5.20240102191335., (continued)
- 12/78: gnu: python-schema-salad: Update to 8.5.20240102191335., guix-commits, 2024/02/23
- 15/78: gnu: Add python-cwl-utils., guix-commits, 2024/02/23
- 17/78: gnu: cwltool: Update to 3.1.20240112164112., guix-commits, 2024/02/23
- 20/78: gnu: virglrenderer: Update to 1.0.1., guix-commits, 2024/02/23
- 29/78: gnu: emacs-auctex: Update to 14.0.3., guix-commits, 2024/02/23
- 30/78: gnu: emacs-mmm-mode: Update to 0.5.11., guix-commits, 2024/02/23
- 40/78: gnu: emacs-dtrt-indent: Update to 1.17., guix-commits, 2024/02/23
- 42/78: gnu: emacs-edit-indirect: Update to 0.1.13., guix-commits, 2024/02/23
- 38/78: gnu: emacs-corfu: Update to 1.2., guix-commits, 2024/02/23
- 49/78: gnu: emacs-goggles: Update to 0.4., guix-commits, 2024/02/23
- 57/78: gnu: emacs-nodejs-repl: Improve package style.,
guix-commits <=
- 60/78: gnu: emacs-parent-mode: Update to 2.3.1., guix-commits, 2024/02/23
- 19/78: gnu: Add xfishtank., guix-commits, 2024/02/23
- 06/78: gnu: vim-dispatch: Update to 1.8-1.4c695bc., guix-commits, 2024/02/23
- 21/78: gnu: spice: Update to 0.15.2., guix-commits, 2024/02/23
- 27/78: gnu: emacs-cider: Update to 1.13.1., guix-commits, 2024/02/23
- 28/78: gnu: emacs-hyperbole: Update to 9.0.0., guix-commits, 2024/02/23
- 31/78: gnu: emacs-pabbrev: Update to 4.3.0., guix-commits, 2024/02/23
- 26/78: gnu: emacs-cape: Update to 1.3., guix-commits, 2024/02/23
- 32/78: gnu: emacs-debbugs: Update to 0.40., guix-commits, 2024/02/23
- 65/78: gnu: emacs-saveplace-pdf-view: Update to 1.0.6., guix-commits, 2024/02/23